<?php
/**
 * One Click Demo Import Functions
 *
 * @package Paper Plane
 */

/**
 * Load custom ocdi styles
 */
function csco_ocdi_admin_enqueue_scripts() {
	wp_enqueue_style( 'csco_ocdi_css', get_template_directory_uri() . '/assets/css/ocdi.css', array(), '1.1.2' );
}
add_action( 'admin_enqueue_scripts', 'csco_ocdi_admin_enqueue_scripts', 100 );

/**
 * Settings Page
 *
 * @param array $default_settings Default settings.
 */
function csco_ocdi_plugin_page_setup( $default_settings ) {
	$data = array(
		'parent_slug' => 'themes.php',
		'page_title'  => esc_html__( 'Demo Content', 'paper-plane' ),
		'menu_title'  => esc_html__( 'Demo Content', 'paper-plane' ),
		'capability'  => 'import',
		'menu_slug'   => 'csco-demo-content',
	);

	return $data;
}
add_filter( 'pt-ocdi/plugin_page_setup', 'csco_ocdi_plugin_page_setup' );

/**
 * Demo Content
 */
function csco_ocdi_import_files() {
	return array(
		array(
			'import_file_name'           => esc_html__( 'Paper Plane', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/paper-plane.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/paper-plane.dat',
			'preview_url'                => 'https://paperplanetheme.com/paperplane/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/paper-plane.png',
		),
		array(
			'import_file_name'           => esc_html__( 'Flatform Studios', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/flatform-studios.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/flatform-studios.dat',
			'preview_url'                => 'https://paperplanetheme.com/flatform-studios/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/flatform-studios.png',
		),
		array(
			'import_file_name'           => esc_html__( 'Dynamic Mechanics', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/dynamic-mechanics.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/dynamic-mechanics.dat',
			'preview_url'                => 'https://paperplanetheme.com/dynamic-mechanics/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/dynamic-mechanics.png',
		),
		array(
			'import_file_name'           => esc_html__( 'Grain', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/grain.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/grain.dat',
			'preview_url'                => 'https://paperplanetheme.com/grain/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/grain.png',
		),
		array(
			'import_file_name'           => esc_html__( 'Solitude', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/solitude.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/solitude.dat',
			'preview_url'                => 'https://paperplanetheme.com/solitude/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/solitude.png',
		),
		array(
			'import_file_name'           => esc_html__( 'Broken Lens', 'paper-plane' ),
			'import_file_url'            => 'https://cloud.codesupply.co/demo-content/paperplane/broken-lens.xml',
			'import_customizer_file_url' => 'https://cloud.codesupply.co/demo-content/paperplane/broken-lens.dat',
			'preview_url'                => 'https://paperplanetheme.com/broken-lens/',
			'import_preview_image_url'   => get_template_directory_uri() . '/inc/demo-import/theme-demos/broken-lens.png',
		),
	);
}
add_filter( 'pt-ocdi/import_files', 'csco_ocdi_import_files' );

/**
 * Page Title
 */
function csco_ocdi_page_title() {
	return '<div class="ocdi__title-container"><h1 class="ocdi__title-container-title">' . esc_html__( 'Demo Content Import', 'paper-plane' ) . '</h1></div>';
}
add_filter( 'pt-ocdi/plugin_page_title', 'csco_ocdi_page_title' );

/**
 * Intro Text
 *
 * @param string $default_text Default Intro Text.
 */
function csco_ocdi_plugin_intro_text( $default_text ) {
	ob_start(); ?>
	<div class="ocdi__intro-text">
		<p class="about-description"><?php esc_html_e( 'Clicking the Import Demo Data button will import demo posts, pages, categories, comments, tags and widgets.', 'paper-plane' ); ?></p>
	</div>
	<?php
	$default_text = ob_get_clean();

	return $default_text;
}
add_filter( 'pt-ocdi/plugin_intro_text', 'csco_ocdi_plugin_intro_text' );

/**
 * Disable Branding
 */
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

/**
 * Import Setup
 */
function csco_ocdi_after_import_setup() {

	$main_menu = get_term_by( 'name', 'Primary', 'nav_menu' );

	set_theme_mod(
		'nav_menu_locations',
		array(
			'primary' => $main_menu->term_id,
			'mobile'  => $main_menu->term_id,
		)
	);

	// Set posts on front page.
	update_option( 'show_on_front', 'posts' );

}
add_action( 'pt-ocdi/after_import', 'csco_ocdi_after_import_setup' );
