<?php
/**
 * Adding New Panels.
 *
 * @package Paper Plane
 */

/**
 * Check display panels for gutenberg panels
 */
function csco_gutenberg_panels_display() {
	// Check Coming Soon Page.
	if ( csco_powerkit_module_enabled( 'coming_soon' ) && powerkit_coming_soon_status() ) {

		$page_id = get_option( 'powerkit_coming_soon_page' );

		if ( (int) get_the_ID() === (int) $page_id ) {
			return;
		}
	}

	return true;
}

/**
 * Register meta fields for gutenberg panels
 */
function csco_gutenberg_panels_register_meta() {

	$post_types = array( 'post', 'page' );

	// Loop Post Types.
	foreach ( $post_types as $post_type ) {

		/**
		 * ==================================
		 * Layout Options
		 * ==================================
		 */
		if ( 'post' === $post_type ) {
			register_post_meta(
				$post_type,
				'csco_page_load_nextpost',
				array(
					'show_in_rest'  => true,
					'type'          => 'string',
					'single'        => true,
					'auth_callback' => function () {
						return current_user_can( 'edit_posts' );
					},
				)
			);
		}

		/**
		 * ==================================
		 * Video Background
		 * ==================================
		 */

		register_post_meta(
			$post_type,
			'csco_post_video_location',
			array(
				'show_in_rest'  => array(
					'schema' => array(
						'type'  => 'array',
						'items' => array(
							'type' => 'string',
						),
					),
				),
				'type'          => 'array',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);

		register_post_meta(
			$post_type,
			'csco_post_video_location_hash',
			array(
				'show_in_rest'  => true,
				'type'          => 'string',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);

		register_post_meta(
			$post_type,
			'csco_post_video_url',
			array(
				'show_in_rest'  => true,
				'type'          => 'string',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);

		register_post_meta(
			$post_type,
			'csco_post_video_bg_start_time',
			array(
				'show_in_rest'  => true,
				'type'          => 'number',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);

		register_post_meta(
			$post_type,
			'csco_post_video_bg_end_time',
			array(
				'show_in_rest'  => true,
				'type'          => 'number',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);

		register_post_meta(
			$post_type,
			'csco_post_text_color',
			array(
				'show_in_rest'  => true,
				'type'          => 'string',
				'single'        => true,
				'auth_callback' => function () {
					return current_user_can( 'edit_posts' );
				},
			)
		);
	}
}
add_action( 'init', 'csco_gutenberg_panels_register_meta' );

/**
 * Filters whether a meta key is considered protected.
 *
 * @param bool   $protected Whether the key is considered protected.
 * @param string $meta_key  Metadata key.
 * @param string $meta_type Type of object metadata is for.
 */
function csco_is_protected_meta( $protected, $meta_key, $meta_type ) {
	$hide_meta_keys = array(
		'csco_post_text_color',
		'csco_page_load_nextpost',
		'csco_post_video_location',
		'csco_post_video_location_hash',
		'csco_post_video_url',
		'csco_post_video_bg_start_time',
		'csco_post_video_bg_end_time',
	);

	if ( in_array( $meta_key, $hide_meta_keys, true ) ) {
		$protected = true;
	}

	return $protected;
}
add_filter( 'is_protected_meta', 'csco_is_protected_meta', 10, 3 );

/**
 * Enqueue assets  for gutenberg panels
 */
function csco_gutenberg_panels_assets() {
	if ( ! csco_gutenberg_panels_display() ) {
		return;
	}

	$post_id = get_the_ID();

	if ( ! $post_id ) {
		return;
	}

	$post = get_post( $post_id );

	$page_static = array();

	// Add pages static.
	$page_static[] = get_option( 'page_on_front' );
	$page_static[] = get_option( 'page_for_posts' );

	$page_load_nextpost = array();

	if ( ! in_array( (string) $post->ID, $page_static, true ) || 'posts' === get_option( 'show_on_front', 'posts' ) ) {
		if ( 'post' === $post->post_type ) {
			$page_load_nextpost = array(
				array(
					'value' => 'default',
					'label' => esc_html__( 'Default', 'paper-plane' ),
				),
				array(
					'value' => 'enabled',
					'label' => esc_html__( 'Enabled', 'paper-plane' ),
				),
				array(
					'value' => 'disabled',
					'label' => esc_html__( 'Disabled', 'paper-plane' ),
				),
			);
		}
	}

	// Set video location list.
	$video_location_list = array(
		array(
			'value' => 'large-header',
			'label' => esc_html__( 'Large Header', 'paper-plane' ),
		),
	);

	if ( 'post' === $post->post_type ) {
		array_push(
			$video_location_list,
			array(
				'value' => 'archive',
				'label' => esc_html__( 'Post Archives', 'paper-plane' ),
			)
		);
	}

	// Enqueue scripts.
	wp_enqueue_script(
		'csco-editor-panels',
		get_template_directory_uri() . '/assets/jsx/panels.js',
		array(
			'wp-i18n',
			'wp-blocks',
			'wp-edit-post',
			'wp-element',
			'wp-editor',
			'wp-components',
			'wp-data',
			'wp-plugins',
			'wp-edit-post',
		),
		csco_get_theme_data( 'Version' ),
		true
	);

	// Localize scripts.
	wp_localize_script(
		'csco-editor-panels',
		'csPanelsData',
		array(
			'postType'          => $post->post_type,
			'pageLoadNextpost'  => $page_load_nextpost,
			'videoLocationList' => $video_location_list,
		)
	);

}
add_action( 'enqueue_block_editor_assets', 'csco_gutenberg_panels_assets' );
