<?php
/**
 * Template Tags
 *
 * Functions that are called directly from template parts or within actions.
 *
 * @package Paper Plane
 */

if ( ! function_exists( 'csco_header_filter_logo' ) ) {
	/**
	 * Header Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_filter_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_class        = null;

		$settings = array_merge( array(
			'variant' => null,
		), $settings );

		// Get default logo.
		$logo_id      = get_theme_mod( $logo_default_name );

		?>
		<svg class="cs-hidden-filter">
			<defs>
				<filter id="logo-1" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="1   0   0   0   0
							0   1   0   0   0
							0   0   1   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
				<filter id="logo-2" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="0   0   0   0   0
							0   0   0   0   0
							0   0   0   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
			</defs>
		</svg>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="cs-logo cs-js-color-toggle">
			<span class="cs-header__logo cs-logo-prev cs-js-color-toggle-prev" data-filter="#logo" style="filter: url(#logo-1);">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</span>
			<span class="cs-header__logo cs-logo-next cs-js-color-toggle-next" data-filter="#logo" style="filter: url(#logo-2);">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</span>
		</a>
		<?php
	}
}

if ( ! function_exists( 'csco_header_logo' ) ) {
	/**
	 * Header Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_class        = null;

		$settings = array_merge( array(
			'variant' => null,
		), $settings );

		// Get default logo.
		$logo_id = get_theme_mod( $logo_default_name );

		?>
		<div class="cs-logo cs-logo_standard">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="cs-header__logo <?php echo esc_attr( $logo_class ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_fullscreen_menu_logo' ) ) {
	/**
	 * Header Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_fullscreen_menu_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_class        = null;

		$settings = array_merge( array(
			'variant' => null,
		), $settings );

		// Get default logo.
		$logo_id = get_theme_mod( $logo_default_name );

		?>
		<div class="cs-logo cs-fullscreen-menu__logo">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="cs-fullscreen-menu__logo <?php echo esc_attr( $logo_class ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_search_logo' ) ) {
	/**
	 * Header Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_search_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_class        = null;

		$settings = array_merge( array(
			'variant' => null,
		), $settings );

		// Get default logo.
		$logo_id = get_theme_mod( $logo_default_name );

		?>
		<div class="cs-logo cs-search__logo">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="cs-search__logo <?php echo esc_attr( $logo_class ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_footer_logo' ) ) {
	/**
	 * Footer Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_class        = null;

		$settings = array_merge( array(
			'variant' => null,
		), $settings );

		// Get default logo.
		$logo_id = get_theme_mod( $logo_default_name );

		?>
		<div class="cs-logo cs-footer__logo">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="cs-footer__logo <?php echo esc_attr( $logo_class ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_header_fullscreen_menu_toggle' ) ) {
	/**
	 * Header Offcanvas Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_fullscreen_menu_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'header_fullscreen_menu', true ) ) {
			return;
		}

		if ( ! csco_is_nav_menu( 'primary' ) ) {
			return;
		}
		?>
		<svg class="cs-hidden-filter">
			<defs>
				<filter id="fullscreen-menu-1" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="1   0   0   0   0
								0   1   0   0   0
								0   0   1   0   0
								0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
				<filter id="fullscreen-menu-2" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="0   0   0   0   0
								0   0   0   0   0
								0   0   0   0   0
								0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
			</defs>
		</svg>
		<span class="cs-header__fullscreen-menu-toggle cs-js-color-toggle" role="button">
			<i class="cs-header__fullscreen-menu-toggle-icon cs-header__fullscreen-menu-toggle-icon_prev cs-js-color-toggle-prev cs-icon cs-icon-menu" data-filter="#fullscreen-menu" style="filter: url(#fullscreen-menu-1)"></i>
			<i class="cs-header__fullscreen-menu-toggle-icon cs-header__fullscreen-menu-toggle-icon_next cs-js-color-toggle-next cs-icon cs-icon-menu" data-filter="#fullscreen-menu" style="filter: url(#fullscreen-menu-2)"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_fullscreen_menu_toggle_mobile' ) ) {
	/**
	 * Header Offcanvas Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_fullscreen_menu_toggle_mobile( $settings = array() ) {
		if ( ! csco_is_nav_menu( 'primary' ) ) {
			return;
		}
		?>
		<span class="cs-header__fullscreen-menu-toggle cs-header__fullscreen-menu-toggle_mobile" role="button">
			<i class="cs-header__fullscreen-menu-toggle-icon cs-icon cs-icon-menu"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_fullscreen_nav_menu' ) ) {
	/**
	 * Fullscreen Nav Menu
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_fullscreen_nav_menu( $settings = array() ) {
		if ( ! csco_is_nav_menu( 'primary' ) ) {
			return;
		}

		$items_wrap_after = '<div class="cs-fullscreen-menu__nav-col cs-fullscreen-menu__nav-col-first"></div>
				<div class="cs-fullscreen-menu__nav-col cs-fullscreen-menu__nav-col-last"></div>';

		wp_nav_menu(
			array(
				'theme_location'  => 'primary',
				'container_class' => 'cs-fullscreen-menu__nav',
				'menu_class'      => 'cs-fullscreen-menu__nav-inner',
				'items_wrap'      => '<ul class="%2$s">%3$s</ul>' . wp_kses( $items_wrap_after, 'csco' ),
			)
		);
	}
}

if ( ! function_exists( 'csco_header_search_toggle' ) ) {
	/**
	 * Header Search Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_search_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'header_search_button', true ) ) {
			return;
		}
		?>
		<svg class="cs-hidden-filter">
			<defs>
				<filter id="search-1" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="1   0   0   0   0
							0   1   0   0   0
							0   0   1   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
				<filter id="search-2" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="0   0   0   0   0
							0   0   0   0   0
							0   0   0   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
			</defs>
		</svg>
		<span class="cs-header__search-toggle cs-js-color-toggle" role="button">
			<i class="cs-header__search-toggle-icon cs-header__search-toggle-icon_prev cs-js-color-toggle-prev cs-icon cs-icon-search" data-filter="#search" style="filter: url(#search-1)"></i>
			<i class="cs-header__search-toggle-icon cs-header__search-toggle-icon_next cs-js-color-toggle-next cs-icon cs-icon-search" data-filter="#search" style="filter: url(#search-2)"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_search_toggle_mobile' ) ) {
	/**
	 * Header Search Toggle Mobile
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_search_toggle_mobile( $settings = array() ) {
		if ( ! get_theme_mod( 'header_search_button', true ) ) {
			return;
		}
		?>
		<span class="cs-header__search-toggle cs-header__search-toggle-mobile" role="button">
			<i class="cs-header__search-toggle-icon cs-icon cs-icon-search"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_scheme_toggle' ) ) {
	/**
	 * Header Scheme Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_scheme_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'color_scheme_toggle', true ) ) {
			return;
		}
		?>
		<svg class="cs-hidden-filter">
			<defs>
				<filter id="scheme-1" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="1   0   0   0   0
							0   1   0   0   0
							0   0   1   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
				<filter id="scheme-2" x="-10%" y="-10%" width="120%" height="120%" filterunits="objectBoundingBox" primitiveunits="userSpaceOnUse" color-interpolation-filters="sRGB">
					<fecolormatrix type="matrix" values="0   0   0   0   0
							0   0   0   0   0
							0   0   0   0   0
							0   0   0   1   0" in="SourceGraphic" result="colormatrix"></fecolormatrix>
				</filter>
			</defs>
		</svg>
		<span role="button" class="cs-header__scheme-toggle cs-site-scheme-toggle cs-js-color-toggle">
			<span class="cs-header__scheme-toggle-icon cs-header__scheme-toggle-icon_prev cs-js-color-toggle-prev" data-filter="#scheme" style="filter: url(#scheme-1)">
				<i class="cs-icon cs-icon-sun"></i>
				<i class="cs-icon cs-icon-moon"></i>
			</span>
			<span class="cs-header__scheme-toggle-icon cs-header__scheme-toggle-icon_next cs-js-color-toggle-next" data-filter="#scheme" style="filter: url(#scheme-2)">
				<i class="cs-icon cs-icon-sun"></i>
				<i class="cs-icon cs-icon-moon"></i>
			</span>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_scheme_toggle_mobile' ) ) {
	/**
	 * Header Scheme Toggle Mobile
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_scheme_toggle_mobile( $settings = array() ) {
		if ( ! get_theme_mod( 'color_scheme_toggle', true ) ) {
			return;
		}
		?>
		<span role="button" class="cs-header__scheme-toggle cs-header__scheme-toggle-mobile cs-site-scheme-toggle">
			<i class=" cs-icon cs-icon-sun"></i>
			<i class=" cs-icon cs-icon-moon"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_fullscreen_menu_social_links' ) ) {
	/**
	 * Fullscreen Menu Social Links
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_fullscreen_menu_social_links( $settings = array() ) {

		if ( ! get_theme_mod( 'fullscreen_menu_social_links', false ) ) {
			return;
		}

		if ( ! csco_powerkit_module_enabled( 'social_links' ) ) {
			return;
		}

		$maximum = get_theme_mod( 'fullscreen_menu_social_links_maximum', 3 );
		$counts  = get_theme_mod( 'fullscreen_menu_social_links_counts', true );

		?>
		<h5><?php esc_html_e( 'Follow Us', 'paper-plane' ); ?></h5>
		<?php

		powerkit_social_links( false, false, $counts, 'columns', 'default', 'mixed', $maximum );
	}
}

if ( ! function_exists( 'csco_footer_copyright' ) ) {
	/**
	 * Footer Copyright
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_copyright( $settings = array() ) {
		/* translators: %s: Author name. */
		$footer_text = get_theme_mod( 'footer_copyright', sprintf( esc_html__( 'Designed & Developed by %s', 'paper-plane' ), '<a href="' . esc_url( csco_get_theme_data( 'AuthorURI' ) ) . '">Code Supply Co.</a>' ) );
		if ( $footer_text ) {
			?>
			<div class="cs-footer__desc">
				<?php echo do_shortcode( $footer_text ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_footer_info' ) ) {
	/**
	 * Footer Info
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_info( $settings = array() ) {
		$footer_info = get_theme_mod( 'footer_info', esc_html__( 'Let\'s make friends ❤️', 'paper-plane' ) );
		if ( $footer_info ) {
			?>
			<div class="cs-footer__info">
				<?php echo do_shortcode( $footer_info ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_footer_nav_menu' ) ) {
	/**
	 * Footer Nav Menu
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_nav_menu( $settings = array() ) {

		$settings = array_merge( array(
			'menu_class' => null,
		), $settings );

		if ( has_nav_menu( 'footer' ) ) {
			wp_nav_menu(
				array(
					'theme_location' => 'footer',
					'menu_class'     => 'cs-footer__nav',
					'container'      => false,
					'depth'          => 1,
				)
			);
		}
	}
}

if ( ! function_exists( 'csco_footer_social_links' ) ) {
	/**
	 * Footer Social Links
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_social_links( $settings = array() ) {

		if ( ! get_theme_mod( 'footer_social_links', false ) ) {
			return;
		}

		if ( ! csco_powerkit_module_enabled( 'social_links' ) ) {
			return;
		}

		$scheme  = get_theme_mod( 'footer_social_links_scheme', 'default' );
		$maximum = get_theme_mod( 'footer_social_links_maximum', 3 );
		$counts  = get_theme_mod( 'footer_social_links_counts', true );
		?>
		<div class="cs-footer-social-links">
			<?php powerkit_social_links( false, false, $counts, 'nav', $scheme, 'mixed', $maximum ); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_the_post_format_icon' ) ) {
	/**
	 * Post Format Icon
	 *
	 * @param string $content After content.
	 */
	function csco_the_post_format_icon( $content = '' ) {
		$post_format = get_post_format();

		if ( 'gallery' === $post_format ) {
			$attachments = count(
				(array) get_children(
					array(
						'post_parent' => get_the_ID(),
						'post_type'   => 'attachment',
					)
				)
			);

			$content = $attachments ? sprintf( '<span>%s</span>', $attachments ) : '';
		}

		if ( $post_format ) {
			?>
			<span class="cs-entry-format">
				<a class="cs-format-icon cs-format-<?php echo esc_attr( $post_format ); ?>" href="<?php the_permalink(); ?>">
					<?php echo wp_kses( $content, 'csco' ); ?>
				</a>
			</span>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_post_author' ) ) {
	/**
	 * Post Author Details
	 *
	 * @param int $id Author ID.
	 */
	function csco_post_author( $id = null ) {
		if ( ! $id ) {
			$id = get_the_author_meta( 'ID' );
		}
		?>
		<div class="cs-meta-author">
			<span class="cs-photo">
				<?php echo get_avatar( $id, '48' ); ?>
			</span>
			<span class="author h6">
				<a href="<?php echo esc_url( get_author_posts_url( $id ) ); ?>" class="url fn n">
					<?php the_author_meta( 'display_name', $id ); ?>
				</a>
			</span>
			<?php if ( csco_powerkit_module_enabled( 'social_links' ) ) { ?>
				<div class="cs-meta-author__social">
					<?php powerkit_author_social_links( $id ); ?>
				</div>
			<?php } ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_archive_post_description' ) ) {
	/**
	 * Post Description in Archive Pages
	 */
	function csco_archive_post_description() {
		$description = get_the_archive_description();
		if ( $description ) {
			?>
			<div class="cs-page__archive-description">
				<?php echo do_shortcode( $description ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_archive_post_count' ) ) {
	/**
	 * Post Count in Archive Pages
	 */
	function csco_archive_post_count() {
		global $wp_query;
		$found_posts = $wp_query->found_posts;
		?>
		<div class="cs-page__archive-count">
			<?php
			/* translators: 1: Singular, 2: Plural. */
			echo esc_html( apply_filters( 'csco_article_full_count', sprintf( _n( '%s post', '%s posts', $found_posts, 'paper-plane' ), $found_posts ), $found_posts ) );
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_subcategories' ) ) {
	/**
	 * Subcategories
	 */
	function csco_subcategories() {

		if ( false === get_theme_mod( 'category_subcategories', false ) ) {
			return;
		}

		if ( ! is_category() ) {
			return;
		}

		$args = apply_filters(
			'csco_subcategories_args',
			array(
				'parent' => get_query_var( 'cat' ),
			)
		);

		$categories = get_categories( $args );

		if ( $categories ) {
			?>
			<div class="cs-page__subcategories">
				<h4><?php esc_html_e( 'Subcategories', 'paper-plane' ); ?></h4>

				<div class="cs-page__tags">
					<ul>
						<?php
						foreach ( $categories as $category ) {
							// Translators: category name.
							$title = sprintf( esc_html__( 'View all posts in %s', 'paper-plane' ), $category->name );
							$link  = get_category_link( $category->term_id )
							?>
								<li>
									<a href="<?php echo esc_url( $link ); ?>" title="<?php echo esc_attr( $title ); ?>">
										<?php echo esc_html( $category->name ); ?>
									</a>
								</li>
							<?php
						}
						?>
					</ul>
				</div>
			</div>
			<?php
		}
	}
}
