<?php
/**
 * Homepage Settings
 *
 * @package Paper Plane
 */

/**
 * Removes default WordPress Static Front Page section
 * and re-adds it in our own panel with the same parameters.
 *
 * @param object $wp_customize Instance of the WP_Customize_Manager class.
 */
function csco_reorder_customizer_settings( $wp_customize ) {

	// Get current front page section parameters.
	$static_front_page = $wp_customize->get_section( 'static_front_page' );

	// Remove existing section, so that we can later re-add it to our panel.
	$wp_customize->remove_section( 'static_front_page' );

	// Re-add static front page section with a new name, but same description.
	$wp_customize->add_section(
		'static_front_page',
		array(
			'title'           => esc_html__( 'Static Front Page', 'paper-plane' ),
			'priority'        => 20,
			'description'     => $static_front_page->description,
			'panel'           => 'home_panel',
			'active_callback' => $static_front_page->active_callback,
		)
	);
}
add_action( 'customize_register', 'csco_reorder_customizer_settings' );

CSCO_Kirki::add_panel(
	'home_panel',
	array(
		'title'    => esc_html__( 'Homepage Settings', 'paper-plane' ),
		'priority' => 50,
	)
);

CSCO_Kirki::add_section(
	'home_settings',
	array(
		'title'    => esc_html__( 'Homepage Layout', 'paper-plane' ),
		'priority' => 15,
		'panel'    => 'home_panel',
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'multicheck',
		'settings' => 'home_post_meta',
		'label'    => esc_html__( 'Post Meta', 'paper-plane' ),
		'section'  => 'home_settings',
		'default'  => array( 'category', 'author', 'date' ),
		'priority' => 10,
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'paper-plane' ),
				'author'       => esc_html__( 'Author', 'paper-plane' ),
				'date'         => esc_html__( 'Date', 'paper-plane' ),
				'views'        => esc_html__( 'Views', 'paper-plane' ),
				'shares'       => esc_html__( 'Shares', 'paper-plane' ),
				'comments'     => esc_html__( 'Comments', 'paper-plane' ),
				'reading_time' => esc_html__( 'Reading Time', 'paper-plane' ),
			)
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'home_pagination_type',
		'label'    => esc_html__( 'Pagination', 'paper-plane' ),
		'section'  => 'home_settings',
		'default'  => 'load-more',
		'priority' => 10,
		'choices'  => array(
			'standard'  => esc_html__( 'Standard', 'paper-plane' ),
			'load-more' => esc_html__( 'Load More Button', 'paper-plane' ),
			'infinite'  => esc_html__( 'Infinite Load', 'paper-plane' ),
		),
	)
);
