<?php
/**
 * Post Settings
 *
 * @package Paper Plane
 */

CSCO_Kirki::add_section(
	'post_settings',
	array(
		'title'    => esc_html__( 'Post Settings', 'paper-plane' ),
		'priority' => 50,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'post_collapsible_common',
		'section'     => 'post_settings',
		'label'       => esc_html__( 'Common', 'paper-plane' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'multicheck',
		'settings' => 'post_meta',
		'label'    => esc_html__( 'Post Meta', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => array( 'category', 'author', 'date' ),
		'priority' => 10,
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'paper-plane' ),
				'date'         => esc_html__( 'Date', 'paper-plane' ),
				'author'       => esc_html__( 'Author', 'paper-plane' ),
				'views'        => esc_html__( 'Views', 'paper-plane' ),
				'shares'       => esc_html__( 'Shares', 'paper-plane' ),
				'comments'     => esc_html__( 'Comments', 'paper-plane' ),
				'reading_time' => esc_html__( 'Reading Time', 'paper-plane' ),
			)
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_author',
		'label'    => esc_html__( 'Display post author', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_tags',
		'label'    => esc_html__( 'Display tags', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_comments_simple',
		'label'    => esc_html__( 'Display comments without the View Comments button', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'collapsible',
			'settings' => 'post_collapsible_subscription_form',
			'section'  => 'post_settings',
			'label'    => esc_html__( 'Subscription Form', 'paper-plane' ),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'checkbox',
			'settings' => 'post_subscribe',
			'label'    => esc_html__( 'Display subscribe section', 'paper-plane' ),
			'section'  => 'post_settings',
			'default'  => false,
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'post_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'paper-plane' ),
			'section'         => 'post_settings',
			'default'         => false,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'post_subscribe_title',
			'label'           => esc_html__( 'Title', 'paper-plane' ),
			'section'         => 'post_settings',
			'default'         => esc_html__( 'Subscribe to Our Newsletter', 'paper-plane' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'post_subscribe_text',
			'label'             => esc_html__( 'Text', 'paper-plane' ),
			'section'           => 'post_settings',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'paper-plane' ),
			'priority'          => 10,
			'sanitize_callback' => 'csco_kses',
			'active_callback'   => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'image',
			'settings'        => 'post_subscribe_image',
			'label'           => esc_html__( 'Background Image', 'paper-plane' ),
			'section'         => 'post_settings',
			'default'         => '',
			'priority'        => 10,
			'choices'         => array(
				'save_as' => 'id',
			),
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_related_posts',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Related Posts', 'paper-plane' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'related',
		'label'    => esc_html__( 'Display related section', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'related_post_meta',
		'label'           => esc_html__( 'Post Meta', 'paper-plane' ),
		'section'         => 'post_settings',
		'default'         => array( 'category', 'author', 'date' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'paper-plane' ),
				'date'         => esc_html__( 'Date', 'paper-plane' ),
				'author'       => esc_html__( 'Author', 'paper-plane' ),
				'views'        => esc_html__( 'Views', 'paper-plane' ),
				'shares'       => esc_html__( 'Shares', 'paper-plane' ),
				'comments'     => esc_html__( 'Comments', 'paper-plane' ),
				'reading_time' => esc_html__( 'Reading Time', 'paper-plane' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'number',
		'settings'        => 'related_number',
		'label'           => esc_html__( 'Maximum Number of Related Posts', 'paper-plane' ),
		'section'         => 'post_settings',
		'default'         => 4,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

if ( csco_post_views_enabled() ) {

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'radio',
			'settings'        => 'related_orderby',
			'label'           => esc_html__( 'Order posts by', 'paper-plane' ),
			'section'         => 'post_settings',
			'default'         => 'rand',
			'priority'        => 10,
			'choices'         => array(
				'rand'       => esc_html__( 'Rand', 'paper-plane' ),
				'date'       => esc_html__( 'Date', 'paper-plane' ),
				'post_views' => esc_html__( 'Views', 'paper-plane' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'related_time_frame',
			'label'           => esc_html__( 'Time Frame', 'paper-plane' ),
			'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'paper-plane' ),
			'section'         => 'post_settings',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'related_orderby',
					'operator' => '==',
					'value'    => 'post_views',
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_load_nextpost',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Auto Load Next Post', 'paper-plane' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_load_nextpost',
		'label'    => esc_html__( 'Enable the Auto Load Next Post feature', 'paper-plane' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_same_category',
		'label'           => esc_html__( 'Auto load posts from the same category only', 'paper-plane' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_reverse',
		'label'           => esc_html__( 'Auto load previous posts instead of next ones', 'paper-plane' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
